Files
xen/tools/misc
Wei Liu 1d069e45f7 mkdeb: use compression level 0
This requires calling dpkg-deb directly and pass it -z0.

It reduces the time to run the mkdeb script from 14 seconds to 3
seconds on my workstation with SSD, from 87s to 15s on a machine
with HDD. The deb file grows from 49M to 58M.

Signed-off-by: Wei Liu <wei.liu2@citrix.com>
Acked-by: Ian Jackson <ian.jackson@eu.citrix.com>
2018-09-07 15:06:00 +01:00
..
2018-09-07 15:06:00 +01:00
2017-10-05 09:27:32 -04:00
2017-06-23 16:08:40 +01:00
…
2018-01-25 12:27:44 +01:00
2010-06-07 07:16:43 +01:00